@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator;
-
+$Games::ABC_Path::Generator::VERSION = '0.4.0';
 use 5.006;
 
 use strict;
@@ -7,60 +7,15 @@ use warnings;
 
 use integer;
 
-use base 'Games::ABC_Path::Generator::Base';
+use parent 'Games::ABC_Path::Generator::Base';
 
 use Games::ABC_Path::Solver::Constants;
-
 use Games::ABC_Path::Solver::Board '0.1.0';
-
 use Games::ABC_Path::MicrosoftRand;
-
 use Games::ABC_Path::Generator::RiddleObj;
 use Games::ABC_Path::Generator::FinalLayoutObj;
 use Games::ABC_Path::Generator::Coord;
 
-=head1 NAME
-
-Games::ABC_Path::Generator - a generator for ABC Path puzzle games.
-
-=head1 VERSION
-
-Version 0.2.1
-
-=cut
-
-our $VERSION = '0.2.1';
-
-
-=head1 SYNOPSIS
-
-    use Games::ABC_Path::Generator;
-
-    my $gen = Games::ABC_Path::Generator->new({seed => 1});
-
-    # Returns a Games::ABC_Path::Generator::RiddleObj object.
-    my $riddle = $gen->calc_riddle();
-
-=head1 DESCRIPTION
-
-ABC Path puzzle games are puzzle games where one is given a 5*5 grid which
-should contain a consecutive path of the letters from 'A' to 'Y' (with vertical,
-horizontal, diagonal, or anti-diagonal steps). The position of the letter 'A'
-is given, and two letters are given for each of the columns, rows, main
-diagonal and main anti-diagonal, which can appear anywhere there.
-
-ABC Path can be played online at L<http://www.brainbashers.com/abcpath.asp> .
-
-This package is a generator for ABC Path games, and it generates a different
-layout with different clues for every random number generator seed.
-
-=head1 SUBROUTINES/METHODS
-
-=head2 my $gen = Games::ABC_Path::Generator->new({seed => $seed});
-
-Initialised a new generator with the random number generator seed $seed .
-
-=cut
 
 sub _init
 {
@@ -142,15 +97,6 @@ sub _get_num_connected
     return scalar keys %connected;
 }
 
-=head2 $gen->calc_final_layout()
-
-Calculates the final, solved, layout of the board based on the current
-random seed.
-
-Returns the layout as a L<Games::ABC_Path::Generator::FinalLayoutObj>
-object.
-
-=cut
 
 sub calc_final_layout
 {
@@ -195,11 +141,6 @@ sub calc_final_layout
     die "Not found!";
 }
 
-=head2 $gen->calc_riddle()
-
-Calculates the riddle (final state + initial hints) and returns it as an object.
-
-=cut
 
 sub _gen_clue_positions {
     my ($self, $cb) = @_;
@@ -377,6 +318,67 @@ sub calc_riddle
     }
 }
 
+
+1; # End of Games::ABC_Path::Generator
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Games::ABC_Path::Generator - a generator for ABC Path puzzle games.
+
+=head1 VERSION
+
+version 0.4.0
+
+=head1 SYNOPSIS
+
+    use Games::ABC_Path::Generator;
+
+    my $gen = Games::ABC_Path::Generator->new({seed => 1});
+
+    # Returns a Games::ABC_Path::Generator::RiddleObj object.
+    my $riddle = $gen->calc_riddle();
+
+=head1 DESCRIPTION
+
+ABC Path puzzle games are puzzle games where one is given a 5*5 grid which
+should contain a consecutive path of the letters from 'A' to 'Y' (with vertical,
+horizontal, diagonal, or anti-diagonal steps). The position of the letter 'A'
+is given, and two letters are given for each of the columns, rows, main
+diagonal and main anti-diagonal, which can appear anywhere there.
+
+ABC Path can be played online at L<http://www.brainbashers.com/abcpath.asp> .
+
+This package is a generator for ABC Path games, and it generates a different
+layout with different clues for every random number generator seed.
+
+=head1 VERSION
+
+version 0.4.0
+
+=head1 SUBROUTINES/METHODS
+
+=head2 my $gen = Games::ABC_Path::Generator->new({seed => $seed});
+
+Initialised a new generator with the random number generator seed $seed .
+
+=head2 $gen->calc_final_layout()
+
+Calculates the final, solved, layout of the board based on the current
+random seed.
+
+Returns the layout as a L<Games::ABC_Path::Generator::FinalLayoutObj>
+object.
+
+=head2 $gen->calc_riddle()
+
+Calculates the riddle (final state + initial hints) and returns it as an object.
+
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
@@ -387,9 +389,6 @@ Please report any bugs or feature requests to C<bug-games-abc_path-generator at
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-ABC_Path-Generator>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -467,7 +466,132 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/games-abc_path-generator/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Games::ABC_Path::Generator
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Games-ABC_Path-Generator>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Games-ABC_Path-Generator>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-ABC_Path-Generator>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Games-ABC_Path-Generator>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Games-ABC_Path-Generator>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Games-ABC_Path-Generator>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/G/Games-ABC_Path-Generator>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Games-ABC_Path-Generator>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Games::ABC_Path::Generator>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-games-abc_path-generator at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-ABC_Path-Generator>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/games-abc_path-generator>
+
+  git clone https://github.com/shlomif/abc-path
 
 =cut
-
-1; # End of Games::ABC_Path::Generator
